# Apologies Python Library

![](https://img.shields.io/pypi/l/apologies.svg)
![](https://img.shields.io/pypi/wheel/apologies.svg)
![](https://img.shields.io/pypi/pyversions/apologies.svg)
![](https://github.com/pronovic/apologies/workflows/Test%20Suite/badge.svg)

[Apologies](https://gitub.com/pronovic/apologies) is a Python library that
implements a game similar to the Sorry board game.  It includes a rudimentary
way to play the game, intended for use by developers and not by end users.

It also serves as a complete example of how to manage a modern (circa 2020)
Python project, including style checks, code formatting, integration with
IntelliJ, CI builds at GitHub, and integration with PyPI and Read the Docs.

*Note:* This is alpha-quality code that is still under active development.
Interfaces may change without warning until the design stabilizes.

